
module Stubbable
  extend ActiveSupport::Concern
  
  included do
    extend(ClassMethods)
    before_save :make_stub
  end
  
  def make_stub
    if !self.stub.blank?
      self.stub = self.stub.parameterize
    else
      self.stub = self.send(self.column).parameterize
    end
    self.errors.add(:stub, "cannot be blank") if self.stub == ''
  end
  
  def column
      # query the class this object belongs to to find the value
      self.class.column
  end
  
  
  module ClassMethods 
    
    def acts_as_stubbable(options={})
      @column = options[:column]
    end
    
    def column
      @column
    end
    
  end

end

class ActiveRecord::Base
  include Stubbable
end

#require File.join(File.dirname(__FILE__), 'stubbable', 'railtie.rb') if defined?(Rails::Railtie)